@@ -83,8 +83,8 @@ def plot_results(solver,geometry,**argv):
          )
 
    #axis = dict(ticktext=[],tickvals= [],showbackground=False)
-
-   bb = str(round(solver['kappa_bte'],2))+' W/m/K' if 'kappa_bte' in solver.keys() else '--'
+ 
+   bb = str(round(solver['kappa_bte'][-1],2))+' W/m/K' if 'kappa_bte' in solver.keys() else '--'
 
    meta  = 'Bulk: ' + str(round(solver['kappa_bulk'],2)) +' W/m/K<br>Fourier: '\
                     +       str(round(solver['kappa_fourier'],2)) + ' W/m/K<br>BTE:' \
@@ -101,7 +101,6 @@ def plot_results(solver,geometry,**argv):
             text=meta,align='left')
 
 
-   #fig.add_annotation(annotations)
 
    fig.update_layout(showlegend=False)
 
